@@ -1,20 +1,18 @@
 from __future__ import annotations
 
-import logging
-
 from typing import Any
 
 from mknodes.basenodes import mknode
-from mknodes.utils import reprhelpers
+from mknodes.utils import log, reprhelpers, resources
 
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 
 class MkKeys(mknode.MkNode):
-    """Node to include other MkPages / Md files."""
+    """Node to display Keyboard shortcuts."""
 
-    REQUIRED_EXTENSIONS = ["pymdownx.keys"]
+    REQUIRED_EXTENSIONS = [resources.Extension("pymdownx.keys")]
     ICON = "fontawesome/regular/keyboard"
 
     def __init__(
@@ -42,13 +40,13 @@ class MkKeys(mknode.MkNode):
         key_str = "+".join(self.keys)
         return f"++{key_str}++"
 
-    @staticmethod
-    def create_example_page(page):
-        import mknodes
+    @classmethod
+    def create_example_page(cls, page):
+        import mknodes as mk
 
-        page += mknodes.MkAdmonition("MkKeys can be used to show Key combinations.")
-        page += mknodes.MkReprRawRendered(MkKeys("M+k+K+e+y+s"))
-        page += mknodes.MkReprRawRendered(MkKeys("Ctrl+A"))
+        page += mk.MkAdmonition("MkKeys can be used to show Key combinations.")
+        page += mk.MkReprRawRendered(MkKeys("M+k+K+e+y+s"))
+        page += mk.MkReprRawRendered(MkKeys("Ctrl+A"))
 
 
 if __name__ == "__main__":
