@@ -1,10 +1,11 @@
 from __future__ import annotations
 
 import dataclasses
-import logging
+
+from mknodes.utils import log
 
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 
 @dataclasses.dataclass
@@ -12,6 +13,7 @@ class EventPlugin:
     flow: list[str]
     help_link: str
     hook_fn_path: str
+    entry_point_group: str
 
 
 MKDOCS_FLOW = [
@@ -44,4 +46,5 @@ mkdocs_plugin = EventPlugin(
     flow=MKDOCS_FLOW,
     help_link="https://www.mkdocs.org/dev-guide/plugins/#{event}",
     hook_fn_path="mkdocs.plugins.BasePlugin.{event}",
+    entry_point_group="mkdocs.plugins",
 )
