@@ -1,11 +1,9 @@
 from __future__ import annotations
 
-import logging
-
-from mknodes.utils import cache
+from mknodes.utils import downloadhelpers, log
 
 
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 URL = "https://pypi.org/pypi/{name}/json"
 
@@ -14,7 +12,7 @@ class PyPiInfo:
     def __init__(self, pkg_name: str):
         self.package_name = pkg_name
         url = URL.format(name=self.package_name)
-        self.response = cache.download_and_cache_url(url, days=1).decode()
+        self.response = downloadhelpers.download(url).decode()
 
 
 if __name__ == "__main__":
