@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-import mknodes
+import mknodes as mk
 
 
 def test_virtual_files():
-    nav = mknodes.MkNav()
+    nav = mk.MkNav()
     subnav = nav.add_nav("subsection")
     page = subnav.add_page("page")
-    img = mknodes.MkBinaryImage(data=b"", path="Test.jpg")
+    img = mk.MkBinaryImage(data=b"", path="Test.jpg")
     page.append(img)
