@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-import mknodes
+import mknodes as mk
 
 
 def test_modulepage():
-    mknodes.MkModulePage(mknodes)
+    mk.MkModulePage(mk)
