@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import pytest
 
-import mknodes
+import mknodes as mk
 
 
 TREE_NUM_PAGES = 5
@@ -12,34 +12,35 @@ TREE_TOTAL = TREE_NUM_PAGES + TREE_NUM_NAVS + TREE_NUM_TEXT
 
 
 def test_nav():
-    nav = mknodes.MkNav()
-    nav.add_doc(mknodes)
+    nav = mk.MkNav()
+    nav.add_doc(mk)
     nav.add_page("Test")
-    nav.add_index_page("Test Index page")
+    nav.add_page("Test Index page", is_index=True)
     nav.add_nav("sub")
 
 
 def test_from_folder(test_data_dir):
-    nav = mknodes.MkNav.from_folder(test_data_dir / "nav_tree")
+    nav = mk.MkNav()
+    nav.parse.folder(test_data_dir / "nav_tree")
     assert len(list(nav.descendants)) == TREE_TOTAL - 1
 
 
 def test_from_file(test_data_dir):
     nav_file = test_data_dir / "nav_tree/SUMMARY.md"
-    # print(pathlib.Path(nav_file).read_text())
-    nav = mknodes.MkNav.from_file(nav_file, None)
+    nav = mk.MkNav()
+    nav.parse.file(nav_file)
     assert len(list(nav.descendants)) == TREE_TOTAL - 1
 
 
 def test_resolved_path():
-    nav = mknodes.MkNav()
+    nav = mk.MkNav()
     subnav = nav.add_nav("subsection")
     subsubnav = subnav.add_nav("subsubsection")
     assert subsubnav.resolved_parts == ("subsection", "subsubsection")
 
 
 def test_creating_module_document():
-    nav = mknodes.MkNav()
+    nav = mk.MkNav()
     subnav = nav.add_nav("subsection")
     module_docs = subnav.add_doc(pytest)
     klasses = list(module_docs.iter_classes())
