@@ -1,10 +1,11 @@
 from __future__ import annotations
 
-import mknodes
+import mknodes as mk
 
 
 def test_page():
-    page = mknodes.MkPage()
+    page = mk.MkPage()
+    page.metadata.pop("created")
     assert not str(page)
 
 
@@ -26,10 +27,8 @@ title: Some title
 
 
 def test_metadata():
-    page = mknodes.MkPage(
-        hide_toc=True,
-        hide_nav=False,
-        hide_path=True,
+    page = mk.MkPage(
+        hide="toc,path",
         search_boost=2.0,
         exclude_from_search=False,
         icon="material/emoticon-happy",
@@ -38,4 +37,5 @@ def test_metadata():
         subtitle="Some subtitle",
         description="Some description",
     )
+    page.metadata.pop("created")
     assert str(page) == EXPECTED
